# Generated by Django 4.2.4 on 2023-10-25 13:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='BaykeClientUser',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('add_date', models.DateTimeField(auto_now_add=True, verbose_name='添加时间')),
                ('pub_date', models.DateTimeField(auto_now=True, verbose_name='修改时间')),
                ('is_delete', models.BooleanField(default=False, editable=False, verbose_name='删除标记')),
                ('username', models.CharField(blank=True, default='', max_length=150, verbose_name='终端名称')),
                ('user_agent', models.CharField(max_length=250, verbose_name='浏览器')),
                ('ip', models.GenericIPAddressField(verbose_name='ip地址')),
                ('stats_date', models.DateField(blank=True, verbose_name='统计日期')),
            ],
            options={
                'verbose_name': '访客',
                'verbose_name_plural': '访客',
                'ordering': ['-add_date'],
            },
        ),
        migrations.CreateModel(
            name='BaykeDataStats',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('add_date', models.DateTimeField(auto_now_add=True, verbose_name='添加时间')),
                ('pub_date', models.DateTimeField(auto_now=True, verbose_name='修改时间')),
                ('is_delete', models.BooleanField(default=False, editable=False, verbose_name='删除标记')),
                ('object_id', models.PositiveIntegerField(blank=True, null=True)),
                ('tag', models.CharField(blank=True, default='', max_length=200, verbose_name='标记')),
                ('pv', models.PositiveIntegerField(default=0, verbose_name='访问量')),
                ('uv', models.PositiveIntegerField(default=0, verbose_name='访客量')),
                ('stats_date', models.DateField(blank=True, verbose_name='统计日期')),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
            options={
                'verbose_name': '浏览量',
                'verbose_name_plural': '浏览量',
                'ordering': ['-add_date'],
            },
        ),
    ]
